#coding=utf-8
#這是lonote翻譯用的引導包，提供給其他模組使用
import gettext, sys, os, locale

import lonote.sxml as sxml
import lonote.path as path

#可用的Locale值
validLanguages = [
        ('default', 'System default language'),
        ('zh_TW', '繁體中文（台灣）'),
        ('zh_CN', '简体中文（大陆）'),
        ('nolocale', 'No locale support')]

def usingLanguage(localeWord):
    '''使用指定的locale（如 zh_TW 等）
    如果輸入「nolocale」則放棄啟用本地化
    如果輸入「default」，用系統語系進行本地化
    如果是其他輸入其他值，則將本地化為指定語系 <- 值不正確等於nolocale'''
    #如果指定為nolocale，就無需啟用locale
    if localeWord == 'nolocale':
        gettext.install('')
    #如果為None，使用系統語系
    elif localeWord == 'default':
        #Windows平台下，先行處理一下環境變數
        if sys.platform.startswith('win'):
            if os.getenv('LANGUAGE') is None: #LONOTE使用LANGUAGE變數值
                lang, enc = locale.getdefaultlocale()
                os.environ['LANGUAGE'] = lang

        gettext.install('lonote', path.localeDir)
    #如果有明確指定localeWord……
    else:
        try:
            local = gettext.translation('lonote', path.localeDir, languages = [localeWord])
            local.install()
        except IOError: #如果找不到指定mo檔案，停用locale功能
            gettext.install('')

def loadLocaleSetting():
    '''嘗試讀取語言設定檔裡面的值
    語言設定檔位置為程式目錄下的language檔案'''
    languageValue = 'default'
    if os.path.isfile(path.language):
        answer = sxml.load(path.language, ['lang'])
        languageValue = answer[0]
    return languageValue

def saveLanguageFile(localeWord = 'default'):
    '''將指定的語系寫入language檔案中'''
    sxml.save(path.language, [('lang',localeWord)])


#用language設定檔中的值作為當前語系
usingLanguage(loadLocaleSetting())
